==> apache-opennlp_1.9.3.orig.tar.gz: apache-opennlp-1.9.3-src/opennlp-tools/src/main/java/opennlp/tools/formats/conllu/ConlluPOSSampleStream.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package opennlp.tools.formats.conllu;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.Objects;

import opennlp.tools.postag.POSSample;
import opennlp.tools.util.FilterObjectStream;
import opennlp.tools.util.ObjectStream;

public class ConlluPOSSampleStream extends FilterObjectStream<ConlluSentence, POSSample> {

  private final ConlluTagset tagset;

  ConlluPOSSampleStream(ObjectStream<ConlluSentence> samples, ConlluTagset tagset) {
    super(samples);
    this.tagset = Objects.requireNonNull(tagset);
  }

  @Override
  public POSSample read() throws IOException {
    ConlluSentence sentence = samples.read();

    if (sentence != null) {
      List<String> tokens = new ArrayList<>();
      List<String> tags = new ArrayList<>();

      for (ConlluWordLine line : sentence.getWordLines()) {
        tokens.add(line.getForm());
        tags.add(line.getPosTag(tagset));
      }

      return new POSSample(tokens, tags);
    }

    return null;
  }
}

==> apache-opennlp_2.3.2.orig.tar.gz: apache-opennlp-2.3.2-src/opennlp-tools/src/main/java/opennlp/tools/formats/conllu/ConlluPOSSampleStream.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package opennlp.tools.formats.conllu;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.Objects;

import opennlp.tools.postag.POSSample;
import opennlp.tools.util.FilterObjectStream;
import opennlp.tools.util.ObjectStream;

public class ConlluPOSSampleStream extends FilterObjectStream<ConlluSentence, POSSample> {

  private final ConlluTagset tagset;

  /**
   * Initializes a {@link ConlluPOSSampleStream}.
   *
   * @param samples The {@link ObjectStream<ConlluSentence> samples} used as input.
   * @param tagset The {@link ConlluTagset} to use. Must not be {@code null}.
   */
  public ConlluPOSSampleStream(ObjectStream<ConlluSentence> samples, ConlluTagset tagset) {
    super(samples);
    this.tagset = Objects.requireNonNull(tagset);
  }

  @Override
  public POSSample read() throws IOException {
    ConlluSentence sentence = samples.read();

    if (sentence != null) {
      List<String> tokens = new ArrayList<>();
      List<String> tags = new ArrayList<>();

      for (ConlluWordLine line : sentence.getWordLines()) {
        tokens.add(line.getForm());
        tags.add(line.getPosTag(tagset));
      }

      return new POSSample(tokens, tags);
    }

    return null;
  }
}
